@@ -47,6 +47,7 @@ class HttpServer(AsyncOnStart, AsyncOnStop):
         interface: str = '0.0.0.0'
         port: int = 80
         client_max_size: int = 100 * (1024 ** 2)
+        max_field_size: int = 16380
 
     def __init__(self, config: Config, *, middleware: Union[Middleware, List[Middleware]] = error_middleware) -> None:
         self.config = config
@@ -63,7 +64,8 @@ class HttpServer(AsyncOnStart, AsyncOnStop):
 
         self.runner = AppRunner(
             web.Application(
-                middlewares=[wrapped_middleware(m) for m in middleware], client_max_size=config.client_max_size
+                middlewares=[wrapped_middleware(m) for m in middleware], client_max_size=config.client_max_size,
+                handler_args={'max_field_size': config.max_field_size}
             )
         )
 
